//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Axis/DiscreteAxis.cpp
//! @brief     Implements class DiscreteAxis.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Base/Axis/DiscreteAxis.h"
#include "Base/Util/VectorUtil.h"

namespace {

std::vector<Bin1D> centers2bins(const std::vector<double>& centers)
{
    std::vector<Bin1D> result;
    for (double c : centers)
        result.emplace_back(Bin1D::At(c));
    return result;
}

} // namespace


IAxis DiscreteAxis(const std::string& name, const std::vector<double>& points)
{
    return IAxis(name, centers2bins(points));
}

IAxis* newDiscreteAxis(const std::string& name, const std::vector<double>& points)
{
    return new IAxis(name, centers2bins(points));
}
