//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Axis/FixedBinAxis.h
//! @brief     Defines class FixedBinAxis.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_BASE_AXIS_FIXEDBINAXIS_H
#define BORNAGAIN_BASE_AXIS_FIXEDBINAXIS_H

#include "Base/Axis/IAxis.h"
#include <memory>

//! Returns axis with fixed bin size.
IAxis FixedBinAxis(const std::string& name, size_t nbins, double start, double end);
IAxis* newFixedBinAxis(const std::string& name, size_t nbins, double start, double end);
std::shared_ptr<IAxis> sharedFixedBinAxis(const std::string& name, size_t nbins, double start,
                                          double end);
std::unique_ptr<IAxis> uniqueFixedBinAxis(const std::string& name, size_t nbins, double start,
                                          double end);

#ifndef SWIG
//! Returns a FixedBinAxis determined by first and last point in scan.
IAxis FixedScanAxis(const std::string& name, size_t nbins, double scan_start, double scan_end);
IAxis* newFixedScanAxis(const std::string& name, size_t nbins, double scan_start, double scan_end);
std::shared_ptr<IAxis> sharedFixedScanAxis(const std::string& name, size_t nbins, double scan_start,
                                           double scan_end);
std::unique_ptr<IAxis> uniqueFixedScanAxis(const std::string& name, size_t nbins, double scan_start,
                                           double scan_end);

#endif

#endif // BORNAGAIN_BASE_AXIS_FIXEDBINAXIS_H
