//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/IO/DataFormatUtil.h
//! @brief     Defines class DatafieldIOFactory.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif // SWIG
#ifndef BORNAGAIN_DEVICE_IO_DATAFORMATUTIL_H
#define BORNAGAIN_DEVICE_IO_DATAFORMATUTIL_H

#include <string>
#include <vector>

class IAxis;
class Datafield;

//! Utility functions for data input and output.

namespace DataUtil::Format {

//! Returns true if name contains *.gz extension
bool isCompressed(const std::string& name);

//! Returns true if name contains *.gz extension
bool isGZipped(const std::string& name);

//! Returns true if name contains *.bz2 extension
bool isBZipped(const std::string& name);

//! Returns true if file name corresponds to BornAgain native format (compressed or not)
bool isIntFile(const std::string& file_name);

//! Returns true if file name corresponds to Nicos format (compressed or not)
bool isNicosFile(const std::string& file_name);

//! Returns true if file name corresponds to tiff file (can be also compressed)
bool isTiffFile(const std::string& file_name);

IAxis* createAxis(std::istream& input_stream);

void fillDatafield(Datafield* data, std::istream& input_stream);

std::vector<double> parse_doubles(const std::string& str);

void readLineOfDoubles(std::vector<double>& buffer, std::istringstream& iss);

} // namespace DataUtil::Format

#endif // BORNAGAIN_DEVICE_IO_DATAFORMATUTIL_H
