//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Import/ImportDataUtil.h
//! @brief     Defines ImportDataUtil namespace
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_IMPORT_IMPORTDATAUTIL_H
#define BORNAGAIN_GUI_VIEW_IMPORT_IMPORTDATAUTIL_H

#include "Device/IO/IOFactory.h"
#include <QString>
#include <memory>

class Datafield;
class RealItem;
class InstrumentItem;
class AbstractDataLoader;

//! Provides utility methods to import data files.

namespace GUI::View::ImportDataUtil {

//! Imports 2D data, stores them as Datafield, and returns owning pointer.
std::unique_ptr<Datafield> Import2dData(const QString& fileName, IOFactory::LoaderSelector loader);

//! Imports 1D data into the given item.

//! Returns an error text if a fatal error occurred (discard item).
//! "Empty string" means "no fatal error" => imported item should be kept.
//! The imported item still can have errors, but they might be solvable
//! by different import settings or by using a different data loader.
//! Argument selectedLoader is the one which was selected in the open-file-dialog
//! (or null if none selected).
QString Import1dData(RealItem* realItem, const AbstractDataLoader* selectedLoader);

} // namespace GUI::View::ImportDataUtil

#endif // BORNAGAIN_GUI_VIEW_IMPORT_IMPORTDATAUTIL_H
